<p align="center">
  <a href="https://github.com/mondeja/mdpo"><img src="https://raw.githubusercontent.com/mondeja/mdpo/master/mdpo.png" alt="mdpo" width="400"></a>
</h1>

<h4 align="center">Markdown file translation utilities using pofiles</h4>

<p align="center">
  <a href="https://pypi.org/project/mdpo/">
    <img src="https://img.shields.io/pypi/v/mdpo"
         alt="PyPI">
  </a>
  <a href="https://pypi.org/project/mdpo/">
    <img src="https://img.shields.io/pypi/pyversions/mdpo?logo=python&logoColor=aaaaaa&labelColor=333333">
  </a>
  <a href="https://github.com/mondeja/mdpo/blob/master/LICENSE">
    <img src="https://img.shields.io/pypi/l/mdpo?color=light-green">
  </a>
</p>

<h2 align="center">
  <a href="https://mdpo.readthedocs.io/en/latest/">Documentation</a>
</h2>

<p align="center">
Fully complies with <a href="https://spec.commonmark.org/0.29">CommonMark Specification v0.29</a>,
supporting some additional features.
</p>

## Status

<!-- mdpo-disable -->

[![Documentation status][doc-image]][doc-link]
[![Tests][tests-image]][tests-link]
[![Coverage status][coverage-image]][coverage-link]

<!-- mdpo-enable -->

## Installation

```bash
pip install mdpo
```

<!-- mdpo-disable -->

> You can see the README introduction translated to other languages using the
> library from [this script][process-locales-script-link]:
>
> - [Spanish][spanish-readme-link]

<!-- mdpo-enable -->


[tests-image]: https://img.shields.io/travis/mondeja/mdpo?label=tests
[tests-link]: https://travis-ci.com/github/mondeja/mdpo
[coverage-image]: https://coveralls.io/repos/github/mondeja/mdpo/badge.svg
[coverage-link]: https://coveralls.io/github/mondeja/mdpo
[doc-image]: https://readthedocs.org/projects/mdpo/badge/?version=latest
[doc-link]: https://mdpo.readthedocs.io/en/latest/
[md4c-build-link]: https://github.com/mity/md4c/wiki/Building-MD4C
[process-locales-script-link]: https://github.com/mondeja/mdpo/blob/master/process-locales.py
[spanish-readme-link]: https://github.com/mondeja/mdpo/blob/master/locale/readme/es.md
